@@ -1,11 +1,11 @@
-# Copyrights 2006-2016 by [Mark Overmeer].
+# Copyrights 2006-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
 
 package XML::Compile::Schema;
 use vars '$VERSION';
-$VERSION = '1.53';
+$VERSION = '1.55';
 
 use base 'XML::Compile';
 
@@ -215,6 +215,11 @@ sub compile($$@)
         panic "require Math::BigFloat by sloppy_floats:\n$@" if $@;
     }
 
+    if($args{json_friendly} ||= 0)
+    {   eval "require Types::Serialiser";
+        panic "require Types::Serialiser by json_friendly:\n$@" if $@;
+    }
+
     $args{prefixes} = $self->_namespaceTable
       (($args{prefixes} || $args{output_namespaces})
       , $args{namespace_reset}
