@@ -1,4 +1,4 @@
-# Copyrights 2006-2016 by [Mark Overmeer].
+# Copyrights 2006-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
@@ -8,7 +8,7 @@ no warnings 'recursion';
 
 package XML::Compile::Schema::BuiltInTypes;
 use vars '$VERSION';
-$VERSION = '1.54';
+$VERSION = '1.55';
 
 use base 'Exporter';
 
@@ -21,6 +21,7 @@ use POSIX           qw/strftime/;
 use Math::BigInt;
 use Math::BigFloat;
 use MIME::Base64;
+use Types::Serialiser;
 
 use XML::Compile::Util qw/pack_type unpack_type/;
 use POSIX              qw/floor log10/;
@@ -78,6 +79,8 @@ $builtin_types{anyAtomicType} =
 
 $builtin_types{error}   = {example => '[some error structure]'};
 
+#----------------
+
 
 $builtin_types{boolean} =
  { parse   => sub { $_[0] =~ m/^\s*false|0\s*/i ? 0 : 1 }
@@ -88,6 +91,16 @@ $builtin_types{boolean} =
  , extends => 'anyAtomicType'
  };
 
+$builtin_types{boolean_with_Types_Serialiser} =
+ { %{$builtin_types{boolean}}
+ , parse => sub {
+       no warnings 'once';
+       $_[0] =~ m/^\s*(false|0)\s*/i
+       ? $Types::Serialiser::false
+       : $Types::Serialiser::true;
+    }
+ };
+
 
 $builtin_types{pattern} =
  { example => '*.exe'
@@ -97,7 +110,7 @@ $builtin_types{pattern} =
 sub bigint
 {   my $v = shift;
     $v =~ s/\s+//g;
-    return $v if $v =~ $fits_iv;
+    return $v+0 if $v =~ $fits_iv;
 
     my $big = Math::BigInt->new($v);
     error __x"Value `{val}' is not a (big) integer", val => $big
@@ -302,6 +315,11 @@ $builtin_types{sloppy_float} =
  , extends => 'anyAtomicType'
  };
 
+$builtin_types{sloppy_float_force_NV} =
+ { %{$builtin_types{sloppy_float}}
+ , parse => sub { $_[0] + 0 }
+ };
+
 
 $builtin_types{base64Binary} =
  { parse   => sub { eval { decode_base64 $_[0] } }
