@@ -1,4 +1,4 @@
-# Copyrights 2006-2016 by [Mark Overmeer].
+# Copyrights 2006-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
@@ -8,7 +8,7 @@ use strict;
 
 package XML::Compile::Schema::Specs;
 use vars '$VERSION';
-$VERSION = '1.53';
+$VERSION = '1.55';
 
 
 use Log::Report 'xml-compile', syntax => 'SHORT';
@@ -162,11 +162,18 @@ sub builtInType($$;$@)
 
     my %args = @_;
 
+    return $builtin_types{boolean_with_Types_Serialiser}
+		if $args{json_friendly} && $name eq 'boolean';
+
     return $builtin_types{$sloppy_int_version{$name}}
         if $args{sloppy_integers} && exists $sloppy_int_version{$name};
 
-    return $builtin_types{$sloppy_float_version{$name}}
-        if $args{sloppy_floats} && exists $sloppy_float_version{$name};
+    if($args{sloppy_floats} && (my $maptype = $sloppy_float_version{$name}))
+    {   return $builtin_types{sloppy_float_force_NV}
+            if $args{json_friendly} && $maptype eq 'sloppy_float';
+
+        return $builtin_types{$maptype};
+    }
 
     # only official names are exported this way
     my $public = $schema->{builtin_public}{$name};
