@@ -1,4 +1,4 @@
-# Copyrights 2006-2016 by [Mark Overmeer].
+# Copyrights 2006-2017 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
@@ -8,7 +8,7 @@ no warnings 'recursion';  # trees can be quite deep
 
 package XML::Compile::Translate;
 use vars '$VERSION';
-$VERSION = '1.53';
+$VERSION = '1.55';
 
 
 # Errors are either in _class 'usage': called with request
@@ -204,7 +204,9 @@ sub topLevel($$;$)
     # built-in types have to be handled differently.
     my $internal = XML::Compile::Schema::Specs->builtInType(undef, $fullname
        , sloppy_integers => $self->{sloppy_integers}
-       , sloppy_floats   => $self->{sloppy_floats});
+       , sloppy_floats   => $self->{sloppy_floats}
+       , json_friendly   => $self->{json_friendly}
+       );
 
     if($internal)
     {   my $builtin = $self->makeBuiltin($fullname, undef
@@ -266,7 +268,9 @@ sub typeByName($$$)
 
     my $def   = XML::Compile::Schema::Specs->builtInType($node, $typename
        , sloppy_integers => $self->{sloppy_integers}
-       , sloppy_floats   => $self->{sloppy_floats});
+       , sloppy_floats   => $self->{sloppy_floats}
+       , json_friendly   => $self->{json_friendly}
+       );
 
     if($def)
     {   # Is built-in
